# easyros
auto install and build ros

## Need
Ubuntun 20.04.6 LTS
## Use
```
pip install easyros
easyros
```

## How can it do now?
install ros simply

## Other
Because I didn't know how to install, I used `https://github.com/fishros/install`  
Thank it
